#!/usr/bin/env python
"""Copyright (c) 2022-2025 mundialis GmbH & Co. KG

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

Setup file for actinia_stac_plugin.
"""

__author__ = "Jorge Herrera, Carmen Tawalika"
__copyright__ = "2021-2025 mundialis GmbH & Co. KG"
__license__ = "GPLv3"

from setuptools import setup

if __name__ == "__main__":
    setup()
